summaryrefslogtreecommitdiffstats
path: root/c++/src/H5Object.h
diff options
context:
space:
mode:
Diffstat (limited to 'c++/src/H5Object.h')
-rw-r--r--c++/src/H5Object.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/c++/src/H5Object.h b/c++/src/H5Object.h
index c4113f1..6d1a752 100644
--- a/c++/src/H5Object.h
+++ b/c++/src/H5Object.h
@@ -85,8 +85,11 @@ class H5_DLLCPP H5Object : public IdComponent {
void removeAttr( const string& name ) const;
void removeAttr( const char* name ) const;
- // Creates a reference to a named H5 object in this object.
- void* Reference(const char* name, H5R_type_t ref_type, DataSpace& dataspace) const;
+ // Creates a reference to a named Hdf5 object in this object.
+ void* Reference(const char* name) const;
+
+ // Creates a reference to a dataset region in this object.
+ void* Reference(const char* name, DataSpace& dataspace, H5R_type_t ref_type = H5R_DATASET_REGION) const;
virtual ~H5Object();